/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.File;
import java.io.IOException;

import java.util.List;
import java.util.Properties;

/**
 * @author Leslie Wong
 */
public class CentralMergePullRequestJob
	extends PortalAcceptancePullRequestJob
	implements SubrepositoryDependentJob {

	public CentralMergePullRequestJob(String url) {
		super(url, "central-merge");

		_subrepositoryName = _getSubrepositoryName(gitWorkingDirectory);

		jobProperties.putAll(
			JenkinsResultsParserUtil.getProperties(
				new File(
					getSubrepositoryWorkingDirectory(), "test.properties")));
	}

	@Override
	public File getSubrepositoryWorkingDirectory() {
		Properties buildProperties = null;

		try {
			buildProperties = JenkinsResultsParserUtil.getBuildProperties();
		}
		catch (IOException ioe) {
			throw new RuntimeException("Unable to get build properties", ioe);
		}

		String subrepositoryDir = JenkinsResultsParserUtil.combine(
			buildProperties.getProperty("base.repository.dir"), "/",
			_subrepositoryName);

		return new File(subrepositoryDir);
	}

	private static String _getSubrepositoryName(
		GitWorkingDirectory gitWorkingDirectory) {

		List<File> currentBranchModifiedFiles =
			gitWorkingDirectory.getModifiedFilesList();

		File modifiedFile = currentBranchModifiedFiles.get(0);

		File moduleDir = modifiedFile.getParentFile();

		File gitrepoFile = new File(moduleDir, ".gitrepo");

		Properties properties = JenkinsResultsParserUtil.getProperties(
			gitrepoFile);

		String subrepositoryRemote = properties.getProperty("remote");

		String subrepositoryName = subrepositoryRemote.replaceAll(
			".*(com-liferay-[^\\.]+)\\.git", "$1");

		if (!subrepositoryName.contains("-private")) {
			subrepositoryName = subrepositoryName + "-private";
		}

		return subrepositoryName;
	}

	private final String _subrepositoryName;

}