/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.File;
import java.io.IOException;

import java.util.Collections;
import java.util.Set;

/**
 * @author Michael Hashimoto
 */
public class PortalReleaseJob
	extends BaseJob implements BatchDependentJob, PortalTestClassJob {

	public PortalReleaseJob(String jobName, String portalBranchName) {
		super(jobName);

		_portalBranchName = portalBranchName;

		try {
			_jenkinsGitWorkingDirectory =
				JenkinsResultsParserUtil.getJenkinsGitWorkingDirectory();

			_portalGitWorkingDirectory =
				JenkinsResultsParserUtil.getPortalGitWorkingDirectory(
					portalBranchName);
		}
		catch (IOException ioe) {
			throw new RuntimeException(
				"Unable to create a Git working directory", ioe);
		}

		jobProperties = JenkinsResultsParserUtil.getProperties(
			new File(
				_portalGitWorkingDirectory.getWorkingDirectory(),
				"test.properties"));

		jobProperties.putAll(
			JenkinsResultsParserUtil.getProperties(
				new File(
					_jenkinsGitWorkingDirectory.getWorkingDirectory(),
					"commands/dependencies/test-portal-release.properties")));
	}

	@Override
	public Set<String> getBatchNames() {
		String testBatchNamesString = JenkinsResultsParserUtil.getProperty(
			jobProperties, "test.batch.names[" + _portalBranchName + "]");

		Set<String> testBatchNames = getSetFromString(testBatchNamesString);

		testBatchNames.addAll(_getOptionalBatchNames());

		return testBatchNames;
	}

	@Override
	public Set<String> getDependentBatchNames() {
		String testBatchNames = JenkinsResultsParserUtil.getProperty(
			jobProperties, "test.batch.names.smoke[" + _portalBranchName + "]");

		return getSetFromString(testBatchNames);
	}

	@Override
	public Set<String> getDistTypes() {
		return Collections.emptySet();
	}

	@Override
	public PortalGitWorkingDirectory getPortalGitWorkingDirectory() {
		return _portalGitWorkingDirectory;
	}

	public void setPortalReleaseRef(String portalReleaseRef) {
		_portalReleaseRef = portalReleaseRef;
	}

	private Set<String> _getOptionalBatchNames() {
		if (_portalReleaseRef == null) {
			return Collections.emptySet();
		}

		String testBatchNamesString = JenkinsResultsParserUtil.getProperty(
			jobProperties,
			"test.batch.names.optional[" + _portalReleaseRef + "]");

		return getSetFromString(testBatchNamesString);
	}

	private final GitWorkingDirectory _jenkinsGitWorkingDirectory;
	private final String _portalBranchName;
	private final PortalGitWorkingDirectory _portalGitWorkingDirectory;
	private String _portalReleaseRef;

}