/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.File;
import java.io.IOException;

import java.util.Set;

/**
 * @author Leslie Wong
 */
public class PortalUpstreamJob
	extends PortalRepositoryJob implements BatchDependentJob {

	public PortalUpstreamJob(String jobName) {
		super(jobName);

		try {
			GitWorkingDirectory jenkinsGitWorkingDirectory =
				JenkinsResultsParserUtil.getJenkinsGitWorkingDirectory();

			jobProperties.putAll(
				JenkinsResultsParserUtil.getProperties(
					new File(
						jenkinsGitWorkingDirectory.getWorkingDirectory(),
						"commands/dependencies" +
							"/test-upstream-batch.properties")));
		}
		catch (IOException ioe) {
			throw new RuntimeException(
				"Unable to create a Git working directory", ioe);
		}
	}

	@Override
	public Set<String> getBatchNames() {
		String testBatchNames = JenkinsResultsParserUtil.getProperty(
			jobProperties,
			"test.batch.names[portal-upstream(" + getBranchName() + ")]");

		return getSetFromString(testBatchNames);
	}

	@Override
	public Set<String> getDependentBatchNames() {
		String testBatchNames = JenkinsResultsParserUtil.getProperty(
			jobProperties, "test.batch.names.smoke[" + getBranchName() + "]");

		return getSetFromString(testBatchNames);
	}

}