/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser.test.clazz.group;

import com.liferay.jenkins.results.parser.JenkinsResultsParserUtil;
import com.liferay.jenkins.results.parser.PortalTestClassJob;

import java.io.File;
import java.io.IOException;

import java.util.List;

/**
 * @author Leslie Wong
 */
public abstract class ModulesBatchTestClassGroup extends BatchTestClassGroup {

	public static class ModulesBatchTestClass extends BaseTestClass {

		protected ModulesBatchTestClass(File moduleBaseDir) {
			super(moduleBaseDir);
		}

		protected void initTestMethods(
			List<File> modulesProjectDirs, File modulesDir, String taskName) {

			for (File modulesProjectDir : modulesProjectDirs) {
				String path = JenkinsResultsParserUtil.getPathRelativeTo(
					modulesProjectDir, modulesDir);

				String moduleTaskCall = JenkinsResultsParserUtil.combine(
					":", path.replaceAll("/", ":"), ":", taskName);

				addTestMethod(moduleTaskCall);
			}
		}

	}

	protected ModulesBatchTestClassGroup(
		String batchName, PortalTestClassJob portalTestClassJob) {

		super(batchName, portalTestClassJob);

		try {
			File modulesDir = new File(
				portalGitWorkingDirectory.getWorkingDirectory(), "modules");

			excludesPathMatchers.addAll(
				getPathMatchers(
					getFirstPropertyValue("modules.excludes"), modulesDir));

			includesPathMatchers.addAll(
				getPathMatchers(
					getFirstPropertyValue("modules.includes"), modulesDir));

			String includedModulesRequired = getFirstPropertyValue(
				"modules.includes.required");

			if (includedModulesRequired != null) {
				includesPathMatchers.addAll(
					getPathMatchers(
						getFirstPropertyValue(includedModulesRequired),
						modulesDir));
			}

			setTestClasses();

			setAxisTestClassGroups();
		}
		catch (IOException ioe) {
			throw new RuntimeException(ioe);
		}
	}

	protected abstract void setTestClasses() throws IOException;

}