/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser.vm.amazon;

/**
 * @author Kiyoshi Lee
 */
public class AuroraAmazonVMFactory {

	public static AuroraAmazonVM getExistingAuroraAmazonVM(
		String awsAccessKeyId, String awsSecretAccessKey, String dbInstanceId) {

		return new MySQLAuroraAmazonVM(
			awsAccessKeyId, awsSecretAccessKey, dbInstanceId);
	}

	public static AuroraAmazonVM newAuroraAmazonVM(
		String awsAccessKeyId, String awsSecretAccessKey, String dbClusterId,
		String dbInstanceClass, String dbInstanceId,
		InstanceType instanceType) {

		if (instanceType == InstanceType.MYSQL) {
			return new MySQLAuroraAmazonVM(
				awsAccessKeyId, awsSecretAccessKey, dbClusterId,
				dbInstanceClass, dbInstanceId);
		}

		if (instanceType == InstanceType.POSTGRESQL) {
			return new PostgreSQLAuroraAmazonVM(
				awsAccessKeyId, awsSecretAccessKey, dbClusterId,
				dbInstanceClass, dbInstanceId);
		}

		throw new IllegalArgumentException("Invalid instance type");
	}

	public static enum InstanceType {

		MYSQL, POSTGRESQL

	}

}